@@ -4,12 +4,8 @@ describe 'sahara::service::api' do
 
   shared_examples_for 'sahara-api' do
 
-    context 'require main class' do
-      it { is_expected.to contain_class('sahara') }
-    end
-
     context 'default params' do
-      it { is_expected.to contain_sahara_config('DEFAULT/api_workers').with_value('0') }
+      it { is_expected.to contain_sahara_config('DEFAULT/api_workers').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'passing params' do
@@ -26,10 +22,10 @@ describe 'sahara::service::api' do
 
   context 'on Debian platforms' do
     let :facts do
-      {
+      @default_facts.merge({
         :osfamily => 'Debian',
         :operatingsystem => 'Debian'
-      }
+      })
     end
 
     it_configures 'sahara-api'
@@ -42,7 +38,7 @@ describe 'sahara::service::api' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'sahara-api'
