@@ -61,10 +61,10 @@ describe 'sahara::logging' do
 
   shared_examples_for 'basic logging options defaults' do
     context 'with defaults' do
-      it { is_expected.to contain_sahara_config('DEFAULT/use_stderr').with_value(true) }
-      it { is_expected.to contain_sahara_config('DEFAULT/use_syslog').with_value(false) }
-      it { is_expected.to contain_sahara_config('DEFAULT/debug').with_value(false) }
-      it { is_expected.to contain_sahara_config('DEFAULT/verbose').with_value(false) }
+      it { is_expected.to contain_sahara_config('DEFAULT/use_stderr').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/use_syslog').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/verbose').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/log_dir').with_value('/var/log/sahara') }
     end
 
@@ -74,7 +74,7 @@ describe 'sahara::logging' do
       end
 
       it { is_expected.to contain_sahara_config('DEFAULT/use_syslog').with_value(true) }
-      it { is_expected.to contain_sahara_config('DEFAULT/syslog_log_facility').with_value('LOG_USER') }
+      it { is_expected.to contain_sahara_config('DEFAULT/syslog_log_facility').with_value('<SERVICE DEFAULT>') }
     end
   end
 
@@ -120,13 +120,13 @@ describe 'sahara::logging' do
      :logging_exception_prefix, :log_config_append, :publish_errors,
      :default_log_levels, :fatal_deprecations, :instance_format,
      :instance_uuid_format, :log_date_format, ].each { |param|
-        it { is_expected.to contain_sahara_config("DEFAULT/#{param}").with_ensure('absent') }
+        it { is_expected.to contain_sahara_config("DEFAULT/#{param}").with_value('<SERVICE DEFAULT>') }
       }
   end
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'sahara-logging'
@@ -134,7 +134,7 @@ describe 'sahara::logging' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'sahara-logging'
